@@ -1,27 +1,26 @@
-import platform
-
 from easyprocess import EasyProcess
 
+from pyscreenshot.plugins.backend import UNKNOWN_VERSION, CBackend
 from pyscreenshot.tempexport import read_prog_img
+from pyscreenshot.util import platform_is_osx
 
 PROGRAM = "screencapture"
 # https://ss64.com/osx/screencapture.html
 #  By default screneshots are saved as .png files,
 
 
-class ScreencaptureWrapper(object):
-    name = "mac_screencapture"
-    childprocess = True
+class ScreencaptureError(Exception):
+    pass
 
-    def __init__(self):
-        if "Darwin" not in platform.platform():
-            raise RunProgError("This backend runs only on Darwin")
-        p = EasyProcess([PROGRAM, "-help"])
-        p.enable_stdout_log = False
-        p.enable_stderr_log = False
-        p.call()
+
+class ScreencaptureWrapper(CBackend):
+    name = "mac_screencapture"
+    is_subprocess = True
 
     def grab(self, bbox=None):
+        if not platform_is_osx():
+            raise ScreencaptureError("This backend runs only on Darwin")
+
         command = [PROGRAM, "-x"]
         if bbox:
             width = bbox[2] - bbox[0]
@@ -31,5 +30,9 @@ class ScreencaptureWrapper(object):
         return im
 
     def backend_version(self):
-        # TODO:
-        return "X.X"
+        p = EasyProcess([PROGRAM, "-help"])
+        p.enable_stdout_log = False
+        p.enable_stderr_log = False
+        p.call()
+        if p.return_code == 0:
+            return UNKNOWN_VERSION
