@@ -3,7 +3,7 @@
 from PIL import Image
 
 from pyscreenshot.plugins.backend import CBackend
-from pyscreenshot.util import py2, py3, py_minor
+from pyscreenshot.util import py_minor
 
 # https://python-mss.readthedocs.io/examples.html
 
@@ -21,15 +21,9 @@ sct = None
 class MssWrapper(CBackend):
     name = "mss"
 
-    def __init__(self):
-        pass
-
     def grab(self, bbox=None):
-        if py2():
+        if py_minor() < 5:
             raise MssError()
-        if py3():
-            if py_minor() < 5:
-                raise MssError()
         import mss
 
         # atexit.register(sct.close())
