@@ -1,10 +1,9 @@
 import os.path
+from tempfile import TemporaryDirectory
 
 from easyprocess import EasyProcess
 from PIL import Image
 
-from pyscreenshot.tempdir import TemporaryDirectory
-
 
 class RunProgError(Exception):
     pass
